@@ -8,7 +8,7 @@ use IO::Compress::Base::Common  2.096 qw(:Status);
 use Compress::Stream::Zstd ;
 use Compress::Stream::Zstd::Decompressor qw(ZSTD_DSTREAM_IN_SIZE);
 our ($VERSION, @ISA);
-$VERSION = '2.096';
+$VERSION = '2.097';
 
 
 sub mkUncompObject
@@ -36,7 +36,7 @@ sub uncompr
 
     my $inf  = $self->{Inf};
 
-    eval { $$to = $inf->decompress($$from); } ;
+    eval { $$to .= $inf->decompress($$from); } ;
 
     if ($@ || $inf->isError())
     {
